==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/pl_pl/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.editcategory.submit_cancel'] = 'Anuluj';
$lang['AdminMain.editcategory.submit_edit'] = 'Kategoria aktualizacji';
$lang['AdminMain.editcategory.field_description'] = 'Opis';
$lang['AdminMain.editcategory.field_name'] = 'Nazwa';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Aktualizacja kategorii [%1$s]';
$lang['AdminMain.editcategory.page_title'] = 'Menedżer pobierania > Kategoria aktualizacji';
$lang['AdminMain.addcategory.submit_cancel'] = 'Anuluj';
$lang['AdminMain.addcategory.submit_add'] = 'Utwórz kategorię';
$lang['AdminMain.addcategory.field_description'] = 'Opis';
$lang['AdminMain.addcategory.field_name'] = 'Nazwa';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Dodaj kategorię do kategorii [%1$s]';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Dodaj kategorię do %1$s';
$lang['AdminMain.addcategory.page_title'] = 'Menedżer pobierania > Dodaj kategorię';
$lang['AdminMain.editurl.submit_cancel'] = 'Anuluj';
$lang['AdminMain.editurl.submit_add'] = 'Edytuj adres URL';
$lang['AdminMain.editurl.field_category'] = 'Kategoria';
$lang['AdminMain.editurl.field_file'] = 'Plik';
$lang['AdminMain.editurl.field_url'] = 'Nazwa URL';
$lang['AdminMain.editurl.boxtitle_add'] = 'Edycja statycznego adresu URL';
$lang['AdminMain.editurl.page_title'] = 'Menedżer pobierania > Edytuj statyczny adres URL';
$lang['AdminMain.edit.submit_cancel'] = 'Anuluj';
$lang['AdminMain.edit.submit_edit'] = 'Aktualizacja do pobrania';
$lang['AdminMain.edit.field_file_name'] = 'Ścieżka do pliku';
$lang['AdminMain.edit.field_file'] = 'Plik';
$lang['AdminMain.edit.field_path'] = 'Określ ścieżkę do pliku';
$lang['AdminMain.edit.field_upload'] = 'Prześlij plik';
$lang['AdminMain.edit.text_availablepackages'] = 'Dostępne pakiety';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Dostępne grupy klientów';
$lang['AdminMain.edit.text_packagegroups'] = 'Wybrane pakiety';
$lang['AdminMain.edit.text_clientgroups'] = 'Wybrane grupy klientów';
$lang['AdminMain.edit.field_available_to_packages'] = 'Dostępne dla pakietów';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Dostępne dla grup klientów';
$lang['AdminMain.edit.field_name'] = 'Nazwa';
$lang['AdminMain.edit.field_logged_in'] = 'Musi być zalogowany';
$lang['AdminMain.edit.field_public'] = 'Publicznie dostępne';
$lang['AdminMain.edit.boxtitle_edit'] = 'Aktualizacja do pobrania';
$lang['AdminMain.edit.page_title'] = 'Menedżer pobierania > Dodaj pobieranie';
$lang['AdminMain.addurl.submit_cancel'] = 'Anuluj';
$lang['AdminMain.addurl.submit_add'] = 'Dodaj adres URL';
$lang['AdminMain.addurl.field_category'] = 'Kategoria';
$lang['AdminMain.addurl.field_file'] = 'Plik';
$lang['AdminMain.addurl.field_url'] = 'Nazwa URL';
$lang['AdminMain.addurl.boxtitle_add'] = 'Dodaj statyczny adres URL';
$lang['AdminMain.addurl.page_title'] = 'Menedżer pobierania > Dodaj statyczny adres URL';
$lang['AdminMain.add.submit_cancel'] = 'Anuluj';
$lang['AdminMain.add.submit_add'] = 'Dodaj pobieranie';
$lang['AdminMain.add.field_file_name'] = 'Ścieżka do pliku';
$lang['AdminMain.add.field_file'] = 'Plik';
$lang['AdminMain.add.field_path'] = 'Określ ścieżkę do pliku';
$lang['AdminMain.add.field_upload'] = 'Prześlij plik';
$lang['AdminMain.add.text_availablepackages'] = 'Dostępne pakiety';
$lang['AdminMain.add.text_availableclientgroups'] = 'Dostępne grupy klientów';
$lang['AdminMain.add.text_packagegroups'] = 'Wybrane pakiety';
$lang['AdminMain.add.text_clientgroups'] = 'Wybrane grupy klientów';
$lang['AdminMain.add.field_available_to_packages'] = 'Dostępne dla pakietów';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Dostępne dla grup klientów';
$lang['AdminMain.add.field_name'] = 'Nazwa';
$lang['AdminMain.add.field_logged_in'] = 'Musi być zalogowany';
$lang['AdminMain.add.field_public'] = 'Publicznie dostępne';
$lang['AdminMain.add.boxtitle_add'] = 'Dodaj pobieranie do kategorii [%1$s]';
$lang['AdminMain.add.boxtitle_root'] = 'Dodaj pobieranie do %1$s';
$lang['AdminMain.add.page_title'] = 'Menedżer pobierania > Dodaj pobieranie';
$lang['AdminMain.urls.no_urls'] = 'W tej sekcji nie ma statycznych adresów URL.';
$lang['AdminMain.urls.latest_file'] = 'Najnowszy plik z <strong>%1$s</strong>';
$lang['AdminMain.urls.delete'] = 'Usuń';
$lang['AdminMain.urls.edit'] = 'Edytuj';
$lang['AdminMain.urls.heading_options'] = 'Opcje';
$lang['AdminMain.urls.heading_link'] = 'Link';
$lang['AdminMain.urls.heading_file'] = 'Plik';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.tab_urls'] = 'Statyczne adresy URL';
$lang['AdminMain.urls.tab_files'] = 'Pliki';
$lang['AdminMain.urls.add_url'] = 'Dodaj statyczny adres URL';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Menedżer pobierania';
$lang['AdminMain.urls.page_title'] = 'Menedżer pobierania > Zarządzaj';
$lang['AdminMain.files.no_downloads'] = 'W tej sekcji nie ma plików do pobrania.';
$lang['AdminMain.files.delete'] = 'Usuń';
$lang['AdminMain.files.edit'] = 'Edytuj';
$lang['AdminMain.files.go_back'] = 'Przejdź na wyższy poziom';
$lang['AdminMain.files.add_category'] = 'Dodaj kategorię tutaj';
$lang['AdminMain.files.add_download'] = 'Dodaj pobieranie tutaj';
$lang['AdminMain.files.tab_urls'] = 'Statyczne adresy URL';
$lang['AdminMain.files.tab_files'] = 'Pliki';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Menedżer pobierania';
$lang['AdminMain.files.page_title'] = 'Menedżer pobierania > Zarządzaj';
$lang['AdminMain.modal.delete_url'] = 'Czy na pewno chcesz usunąć ten statyczny adres URL?';
$lang['AdminMain.modal.delete_category'] = 'Czy na pewno chcesz usunąć tę kategorię? Wszystkie podkategorie i pliki w tej kategorii zostaną przeniesione do kategorii nadrzędnej.';
$lang['AdminMain.modal.delete_file'] = 'Czy na pewno chcesz usunąć ten plik?';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.root_directory'] = 'Katalog domowy';
$lang['AdminMain.!tooltip.category_type'] = 'Adres URL będzie wskazywał na ostatni plik przesłany do tej kategorii.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Wprowadź bezwzględną ścieżkę do pliku w systemie plików.';
$lang['AdminMain.!success.url_updated'] = 'Statyczny adres URL został pomyślnie zaktualizowany.';
$lang['AdminMain.!success.url_added'] = 'Statyczny adres URL został pomyślnie dodany.';
$lang['AdminMain.!success.url_deleted'] = 'Statyczny adres URL został pomyślnie usunięty.';
$lang['AdminMain.!success.file_deleted'] = 'Plik został pomyślnie usunięty.';
$lang['AdminMain.!success.file_updated'] = 'Plik został pomyślnie zaktualizowany.';
$lang['AdminMain.!success.file_added'] = 'Plik został pomyślnie dodany.';
$lang['AdminMain.!success.category_deleted'] = 'Kategoria została pomyślnie usunięta.';
$lang['AdminMain.!success.category_updated'] = 'Kategoria została pomyślnie zaktualizowana.';
$lang['AdminMain.!success.category_added'] = 'Kategoria została pomyślnie utworzona.';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/pl_pl/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.editcategory.submit_cancel'] = 'Anuluj';
$lang['AdminMain.editcategory.submit_edit'] = 'Kategoria aktualizacji';
$lang['AdminMain.editcategory.field_description'] = 'Opis';
$lang['AdminMain.editcategory.field_name'] = 'Nazwa';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Aktualizacja kategorii [%1$s]';
$lang['AdminMain.editcategory.page_title'] = 'Menedżer pobierania > Kategoria aktualizacji';
$lang['AdminMain.addcategory.submit_cancel'] = 'Anuluj';
$lang['AdminMain.addcategory.submit_add'] = 'Utwórz kategorię';
$lang['AdminMain.addcategory.field_description'] = 'Opis';
$lang['AdminMain.addcategory.field_name'] = 'Nazwa';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Dodaj kategorię do kategorii [%1$s]';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Dodaj kategorię do %1$s';
$lang['AdminMain.addcategory.page_title'] = 'Menedżer pobierania > Dodaj kategorię';
$lang['AdminMain.editurl.submit_cancel'] = 'Anuluj';
$lang['AdminMain.editurl.submit_add'] = 'Edytuj adres URL';
$lang['AdminMain.editurl.field_category'] = 'Kategoria';
$lang['AdminMain.editurl.field_file'] = 'Plik';
$lang['AdminMain.editurl.field_url'] = 'Nazwa URL';
$lang['AdminMain.editurl.boxtitle_add'] = 'Edycja statycznego adresu URL';
$lang['AdminMain.editurl.page_title'] = 'Menedżer pobierania > Edytuj statyczny adres URL';
$lang['AdminMain.edit.submit_cancel'] = 'Anuluj';
$lang['AdminMain.edit.submit_edit'] = 'Aktualizacja do pobrania';
$lang['AdminMain.edit.field_file_name'] = 'Ścieżka do pliku';
$lang['AdminMain.edit.field_file'] = 'Plik';
$lang['AdminMain.edit.field_path'] = 'Określ ścieżkę do pliku';
$lang['AdminMain.edit.field_upload'] = 'Prześlij plik';
$lang['AdminMain.edit.text_availablepackages'] = 'Dostępne pakiety';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Dostępne grupy klientów';
$lang['AdminMain.edit.text_packagegroups'] = 'Wybrane pakiety';
$lang['AdminMain.edit.text_clientgroups'] = 'Wybrane grupy klientów';
$lang['AdminMain.edit.field_available_to_packages'] = 'Dostępne dla pakietów';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Dostępne dla grup klientów';
$lang['AdminMain.edit.field_name'] = 'Nazwa';
$lang['AdminMain.edit.field_logged_in'] = 'Musi być zalogowany';
$lang['AdminMain.edit.field_public'] = 'Publicznie dostępne';
$lang['AdminMain.edit.boxtitle_edit'] = 'Aktualizacja do pobrania';
$lang['AdminMain.edit.page_title'] = 'Menedżer pobierania > Dodaj pobieranie';
$lang['AdminMain.addurl.submit_cancel'] = 'Anuluj';
$lang['AdminMain.addurl.submit_add'] = 'Dodaj adres URL';
$lang['AdminMain.addurl.field_category'] = 'Kategoria';
$lang['AdminMain.addurl.field_file'] = 'Plik';
$lang['AdminMain.addurl.field_url'] = 'Nazwa URL';
$lang['AdminMain.addurl.boxtitle_add'] = 'Dodaj statyczny adres URL';
$lang['AdminMain.addurl.page_title'] = 'Menedżer pobierania > Dodaj statyczny adres URL';
$lang['AdminMain.add.submit_cancel'] = 'Anuluj';
$lang['AdminMain.add.submit_add'] = 'Dodaj pobieranie';
$lang['AdminMain.add.field_file_name'] = 'Ścieżka do pliku';
$lang['AdminMain.add.field_file'] = 'Plik';
$lang['AdminMain.add.field_path'] = 'Określ ścieżkę do pliku';
$lang['AdminMain.add.field_upload'] = 'Prześlij plik';
$lang['AdminMain.add.text_availablepackages'] = 'Dostępne pakiety';
$lang['AdminMain.add.text_availableclientgroups'] = 'Dostępne grupy klientów';
$lang['AdminMain.add.text_packagegroups'] = 'Wybrane pakiety';
$lang['AdminMain.add.text_clientgroups'] = 'Wybrane grupy klientów';
$lang['AdminMain.add.field_available_to_packages'] = 'Dostępne dla pakietów';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Dostępne dla grup klientów';
$lang['AdminMain.add.field_name'] = 'Nazwa';
$lang['AdminMain.add.field_logged_in'] = 'Musi być zalogowany';
$lang['AdminMain.add.field_public'] = 'Publicznie dostępne';
$lang['AdminMain.add.boxtitle_add'] = 'Dodaj pobieranie do kategorii [%1$s]';
$lang['AdminMain.add.boxtitle_root'] = 'Dodaj pobieranie do %1$s';
$lang['AdminMain.add.page_title'] = 'Menedżer pobierania > Dodaj pobieranie';
$lang['AdminMain.urls.no_urls'] = 'W tej sekcji nie ma statycznych adresów URL.';
$lang['AdminMain.urls.latest_file'] = 'Najnowszy plik z <strong>%1$s</strong>';
$lang['AdminMain.urls.delete'] = 'Usuń';
$lang['AdminMain.urls.edit'] = 'Edytuj';
$lang['AdminMain.urls.heading_options'] = 'Opcje';
$lang['AdminMain.urls.heading_link'] = 'Link';
$lang['AdminMain.urls.heading_file'] = 'Plik';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.tab_urls'] = 'Statyczne adresy URL';
$lang['AdminMain.urls.tab_files'] = 'Pliki';
$lang['AdminMain.urls.add_url'] = 'Dodaj statyczny adres URL';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Menedżer pobierania';
$lang['AdminMain.urls.page_title'] = 'Menedżer pobierania > Zarządzaj';
$lang['AdminMain.files.no_downloads'] = 'W tej sekcji nie ma plików do pobrania.';
$lang['AdminMain.files.delete'] = 'Usuń';
$lang['AdminMain.files.edit'] = 'Edytuj';
$lang['AdminMain.files.go_back'] = 'Przejdź na wyższy poziom';
$lang['AdminMain.files.add_category'] = 'Dodaj kategorię tutaj';
$lang['AdminMain.files.add_download'] = 'Dodaj pobieranie tutaj';
$lang['AdminMain.files.tab_urls'] = 'Statyczne adresy URL';
$lang['AdminMain.files.tab_files'] = 'Pliki';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Menedżer pobierania';
$lang['AdminMain.files.page_title'] = 'Menedżer pobierania > Zarządzaj';
$lang['AdminMain.modal.delete_url'] = 'Czy na pewno chcesz usunąć ten statyczny adres URL?';
$lang['AdminMain.modal.delete_category'] = 'Czy na pewno chcesz usunąć tę kategorię? Wszystkie podkategorie i pliki w tej kategorii zostaną przeniesione do kategorii nadrzędnej.';
$lang['AdminMain.modal.delete_file'] = 'Czy na pewno chcesz usunąć ten plik?';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.root_directory'] = 'Katalog domowy';
$lang['AdminMain.!tooltip.category_type'] = 'Adres URL będzie wskazywał na ostatni plik przesłany do tej kategorii.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Wprowadź bezwzględną ścieżkę do pliku w systemie plików.';
$lang['AdminMain.!success.url_updated'] = 'Statyczny adres URL został pomyślnie zaktualizowany.';
$lang['AdminMain.!success.url_added'] = 'Statyczny adres URL został pomyślnie dodany.';
$lang['AdminMain.!success.url_deleted'] = 'Statyczny adres URL został pomyślnie usunięty.';
$lang['AdminMain.!success.file_deleted'] = 'Plik został pomyślnie usunięty.';
$lang['AdminMain.!success.file_updated'] = 'Plik został pomyślnie zaktualizowany.';
$lang['AdminMain.!success.file_added'] = 'Plik został pomyślnie dodany.';
$lang['AdminMain.!success.category_deleted'] = 'Kategoria została pomyślnie usunięta.';
$lang['AdminMain.!success.category_updated'] = 'Kategoria została pomyślnie zaktualizowana.';
$lang['AdminMain.!success.category_added'] = 'Kategoria została pomyślnie utworzona.';
$lang['AdminMain.edit.text_full_path'] = 'UWAGA: Pliki muszą znajdować się w katalogu uploads: <strong>%1$s</strong>.';
$lang['AdminMain.add.text_full_path'] = 'UWAGA: Pliki muszą znajdować się w katalogu uploads: <strong>%1$s</strong>.';
